@@ -92,6 +92,10 @@ int _gnutls_buffer_append_printf (gnutls_buffer_st * dest, const char *fmt,
                                   ...)
   __attribute__ ((format (printf, 2, 3)));
 
+void _gnutls_buffer_hexprint (gnutls_buffer_st * str, const char *data, size_t len);
+void _gnutls_buffer_hexdump (gnutls_buffer_st * str, const char *data, size_t len,
+         const char *spc);
+
 char *_gnutls_bin2hex (const void *old, size_t oldlen, char *buffer,
                        size_t buffer_size, const char *separator);
 int _gnutls_hex2bin (const opaque * hex_data, int hex_size, opaque * bin_data,
@@ -99,6 +103,7 @@ int _gnutls_hex2bin (const opaque * hex_data, int hex_size, opaque * bin_data,
 
 int _gnutls_hostname_compare (const char *certname, size_t certnamesize,
                               const char *hostname, int level);
+
 #define MAX_CN 256
 #define MAX_DN 1024
 
