@@ -1,13 +1,17 @@
 #define PORT 5556
 #define SERVER "127.0.0.1"
 
+#include <config.h>
 #include <gnutls/gnutls.h>
 
 #include <sys/socket.h>
 #include <netdb.h>
 #include <unistd.h>
-#include <netinet/in.h>
-#include <netinet/ip.h>
+#ifndef _WIN32
+# include <netinet/in.h>
+# include <netinet/ip.h>
+#endif
+
 #include <signal.h>
 #ifdef _WIN32
 #include <io.h>
